.. _api::

API Reference
=============

.. automodule:: aurora
    :show-inheritance:


.. toctree::
    :maxdepth: 2
    :caption: API documentation

    time_series
    transfer_function
    pipelines
    interval
    general_helper_functions
